/*
 * Copyright 2008-2011 Femke Ongenae, Stijn Verstichel
 * distributed under the terms of the AGPL License
 * 
 * This file is part of OTAGen.
 * 
 * OTAGen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Femke Ongenae & Stijn Verstichel
 * Ghent University - INTEC - IBCN
 * Zuiderpoort Block C0 bus 201
 * Gaston Crommenlaan 8
 * B-9050 Ghent
 * Belgium
 * E-mail: Femke.Ongenae@intec.ugent.be
 * E-mail: Stijn.Verstichel@intec.ugent.be
 * 
 */
package otagen.feedback;

import com.hp.hpl.jena.ontology.OntClass;
import com.hp.hpl.jena.ontology.OntProperty;
import com.hp.hpl.jena.ontology.OntResource;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import otagen.datatypes.Cluster;
import otagen.datatypes.IndividualCount;
import otagen.datatypes.RelationCount;

/**
 * Class used to give feedback information about the creation of the instance
 * level of the ontology eg. the number of individuals,...
 *
 * @author Femke Ongenae.
 * @author Stijn Verstichel.
 */
public class AboxInformation {

    private boolean debug = false;
    private List<Cluster> generatedClusters = null;
    private IndividualCount individualCount = null;
    private Set<RelationCount> relationCount = null;

    /** Creates a new instance of AboxInformation */
    public AboxInformation() {
        generatedClusters = new ArrayList<Cluster>();
        individualCount = new IndividualCount();
        relationCount = new HashSet<RelationCount>();
    }

    public List<Cluster> getGeneratedClusters() {
        return generatedClusters;
    }

    public void setGeneratedClusters(List<Cluster> generatedClusters) {
        this.generatedClusters = generatedClusters;
    }

    public IndividualCount getIndividualCount() {
        return individualCount;
    }

    public void setIndividualCount(IndividualCount individualCount) {
        this.individualCount = individualCount;
    }

    public Set<RelationCount> getRelationCount() {
        return relationCount;
    }

    public void setRelationCount(Set<RelationCount> relationCount) {
        this.relationCount = relationCount;
    }

    public void addRelationInstance(OntClass domain, OntClass range,
            OntProperty property) {
        if (debug) {
            System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                    "Domain: " + domain + " Range: " + range +
                    " Property: " + property);
        }

        Iterator<RelationCount> it = relationCount.iterator();
        boolean added = false;
        RelationCount rc = null;
        while (it.hasNext() && !added) {
            rc = it.next();
            //System.out.println(rc);
            if (rc.getRange() == null) {
                if (domain.getURI().equalsIgnoreCase(rc.getDomain().getURI()) &&
                        property.getURI().equalsIgnoreCase(rc.getProperty().getURI())) {
                    rc.setCount(rc.getCount() + 1);

                    if (debug) {
                        System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                                "Increased count");
                    }
                    added = true;
                }
            } else if (domain.getURI().equalsIgnoreCase(rc.getDomain().getURI()) &&
                    range.getURI().equalsIgnoreCase(rc.getRange().getURI()) &&
                    property.getURI().equalsIgnoreCase(rc.getProperty().getURI())) {
                rc.setCount(rc.getCount() + 1);

                if (debug) {
                    System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                            "Increased count");
                }
                added = true;
            }
        }
        if (!added) {
            rc = new RelationCount();
            rc.setDomain(domain);
            rc.setRange(range);
            rc.setProperty(property);
            rc.setCount(1);
            relationCount.add(rc);
            if (debug) {
                System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                        "Added new RC: " + relationCount.size());
            }
        }
    }

    public void addRelationInstance(OntClass domain, OntResource range,
            OntProperty property) {
        if (debug) {
            System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                    "Domain: " + domain + " Range: " + range +
                    " Property: " + property);
        }

        Iterator<RelationCount> it = relationCount.iterator();
        boolean added = false;
        RelationCount rc = null;
        while (it.hasNext() && !added) {
            rc = it.next();
            if (domain.getURI().equalsIgnoreCase(rc.getDomain().getURI()) &&
                    property.getURI().equalsIgnoreCase(rc.getProperty().getURI())) {
                rc.setCount(rc.getCount() + 1);
                if (debug) {
                    System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                            "Increased count");
                }

                added = true;
            }

        }
        if (!added) {
            rc = new RelationCount();
            rc.setDomain(domain);
            rc.setRangeR(range);
            rc.setProperty(property);
            rc.setCount(1);
            relationCount.add(rc);
            if (debug) {
                System.out.println("[ADDRELATIONINSTANCE][DEBUG] " +
                        "Added new RC: " + relationCount.size());
            }
        }
    }
}
