/*
 * Copyright 2008-2011 Femke Ongenae, Stijn Verstichel
 * distributed under the terms of the AGPL License
 * 
 * This file is part of OTAGen.
 * 
 * OTAGen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Femke Ongenae & Stijn Verstichel
 * Ghent University - INTEC - IBCN
 * Zuiderpoort Block C0 bus 201
 * Gaston Crommenlaan 8
 * B-9050 Ghent
 * Belgium
 * E-mail: Femke.Ongenae@intec.ugent.be
 * E-mail: Stijn.Verstichel@intec.ugent.be
 * 
 */

package otagen.feedback;

/**
 * Class used to give feedback information about the creation of the class
 * hierarchie of the ontology eg. the number of classes, subclasses and so on.
 *
 * @author Femke Ongenae.
 * @author Stijn Verstichel.
 */
public class ClassInformation {
    
    /////-------------------------FIELDS-------------------------/////
    
    //Counts the number of empty classes (classes without a definition)
    //that have been created.
    private int nrOfEmptyClasses = 0;
    
    //Counts the number of union (logical) classes that have been created.
    private int nrOfUnionClasses = 0;
    
    //Counts the number of intersection (logical) classes 
    //that have been created.
    private int nrOfIntersectionClasses = 0;
    
    //Counts the number of complement (logical) classes that have been created.
    private int nrOfComplementClasses = 0;
    
    //Counts the number of enumerated (logical) classes that have been created.
    private int nrOfEnumClasses = 0;
    
    //Counts the number of restriction (logical) classes that have been created.
    private int nrOfRestrictionClasses = 0;
    
    //The depth of the tree of the simple (not logical) classes.
    private int simpleDepth = 0;
    
    /////-------------------------Constructor-------------------------/////
    
    /** Creates a new instance of ClassInformation */
    public ClassInformation() {
    }
    
    /////-------------------------Getters/Setters-------------------------/////
    
    /**
     * Gets the number of empty classes (classes without a definition) that
     * have been created.
     *
     * @return int: the number of empty classes that have been created.
     */
    public int getNrOfEmptyClasses() {
        return nrOfEmptyClasses;
    }
    
    /**
     * Sets the number of empty classes (classes without a definition) that
     * have been created.
     *
     * @param int nrOfEmptyClasses: the number of empty classes 
     *                              that have been created.
     */
    public void setNrOfEmptyClasses(int nrOfEmptyClasses) {
        this.nrOfEmptyClasses = nrOfEmptyClasses;
    }
    
    /**
     * Gets the number of union (logical) classes that have been created.
     *
     * @return int: the number of union classes that have been created.
     */
    public int getNrOfUnionClasses() {
        return nrOfUnionClasses;
    }
    
    /**
     * Sets the number of union (logical) classes that have been created.
     *
     * @param int nrOfUnionClasses: the number of union classes 
     *                              that have been created.
     */
    public void setNrOfUnionClasses(int nrOfUnionClasses) {
        this.nrOfUnionClasses = nrOfUnionClasses;
    }
    
    /**
     * Gets the number of intersection (logical) classes that have been created.
     *
     * @return int: the number of intersection classes that have been created.
     */
    public int getNrOfIntersectionClasses() {
        return nrOfIntersectionClasses;
    }
    
    /**
     * Sets the number of intersection (logical) classes that have been created.
     *
     * @param int nrOfIntersectionClasses: the number of intersection classes 
     *                                     that have been created.
     */
    public void setNrOfIntersectionClasses(int nrOfIntersectionClasses) {
        this.nrOfIntersectionClasses = nrOfIntersectionClasses;
    }
    
    /**
     * Gets the number of complement (logical) classes that have been created.
     *
     * @return int: the number of complement classes that have been created.
     */
    public int getNrOfComplementClasses() {
        return nrOfComplementClasses;
    }
    
    /**
     * Sets the number of complement (logical) classes that have been created.
     *
     * @param int nrOfComplementClasses: the number of complement classes 
     *                                   that have been created.
     */
    public void setNrOfComplementClasses(int nrOfComplementClasses) {
        this.nrOfComplementClasses = nrOfComplementClasses;
    }
    
    /**
     * Gets the number of enumerated (logical) classes that have been created.
     *
     * @return int: the number of enumerated classes that have been created.
     */
    public int getNrOfEnumClasses() {
        return nrOfEnumClasses;
    }
    
    /**
     * Sets the number of enumerated (logical) classes that have been created.
     *
     * @param int nrOfEnumClasses: the number of enumerated classes 
     *                             that have been created.
     */
    public void setNrOfEnumClasses(int nrOfEnumClasses) {
        this.nrOfEnumClasses = nrOfEnumClasses;
    }
    
    /**
     * Gets the number of restriction (logical) classes that have been created.
     *
     * @return int: the number of restriction classes that have been created.
     */
    public int getNrOfRestrictionClasses() {
        return nrOfRestrictionClasses;
    }
    
    /**
     * Sets the number of restriction (logical) classes that have been created.
     *
     * @param int nrOfRestrictionClasses: the number of restriction classes 
     *                                    that have been created.
     */
    public void setNrOfRestrictionClasses(int nrOfRestrictionClasses) {
        this.nrOfRestrictionClasses = nrOfRestrictionClasses;
    }

    /**
     * Gets the depth of the simple (not logical) class tree.
     *
     * @return int: the depth of the simple (not logical) class tree.
     */        
    public int getSimpleDepth() {
        return simpleDepth;
    }

    /**
     * Sets the depth of the simple (not logical) class tree.
     *
     * @param int simpleDepth: the depth of the simple (not logical) class tree.
     */ 
    public void setSimpleDepth(int simpleDepth) {
        this.simpleDepth = simpleDepth;
    }
    
}
