/*
 * Copyright 2008-2011 Femke Ongenae, Stijn Verstichel
 * distributed under the terms of the AGPL License
 * 
 * This file is part of OTAGen.
 * 
 * OTAGen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Femke Ongenae & Stijn Verstichel
 * Ghent University - INTEC - IBCN
 * Zuiderpoort Block C0 bus 201
 * Gaston Crommenlaan 8
 * B-9050 Ghent
 * Belgium
 * E-mail: Femke.Ongenae@intec.ugent.be
 * E-mail: Stijn.Verstichel@intec.ugent.be
 * 
 */

package otagen.feedback;

/**
 * Class used to give feedback information about the creation of the conceptual level
 * of the ontology eg. the number of classes, properties and so on.
 *
 * @author Femke Ongenae.
 * @author Stijn Verstichel.
 */
public class TboxInformation {
    
    /////-------------------------FIELDS-------------------------/////
    
    
    //holds the information about the generated classes.
    private ClassInformation classInformation = null;
    
    //holds the information about the generated datatype properties.
    private DatatypeInformation datatypeInformation = null;
    
    //holds the information about the generated object properties.
    private ObjectInformation objectInformation = null;
   
    /////-------------------------Constructor-------------------------/////
    
    /** Creates a new instance of TboxInformation */
    public TboxInformation() {
    }

    /////-------------------------Getters/Setters-------------------------/////
    
    /**
     * Gets the information about the generated classes.
     * 
     * @return ClassInformation: information about the generated classes.
     */
    public ClassInformation getClassInformation() {
        return classInformation;
    }

    /**
     * Sets the information about the generated classes.
     * 
     * @param ClassInformation classInformation: information about the generated classes.
     */
    public void setClassInformation(ClassInformation classInformation) {
        this.classInformation = classInformation;
    }

    /**
     * Gets the information about the generated datatype properties.
     * 
     * @return DatatypeInformation: information about the generated datatype properties.
     */
    public DatatypeInformation getDatatypeInformation() {
        return datatypeInformation;
    }

    /**
     * Sets the information about the generated datatype properties.
     * 
     * @param DatatypeInformation datatypeInformation: information about the generated datatype properties.
     */
    public void setDatatypeInformation(DatatypeInformation datatypeInformation) {
        this.datatypeInformation = datatypeInformation;
    }

    /**
     * Gets the information about the generated object properties.
     * 
     * @return ObjectInformation: information about the generated object properties.
     */
    public ObjectInformation getObjectInformation() {
        return objectInformation;
    }

    /**
     * Sets the information about the generated object properties.
     * 
     * @param ObjectInformation objectInformation: information about the generated object properties.
     */      
    public void setObjectInformation(ObjectInformation objectInformation) {
        this.objectInformation = objectInformation;
    }
    
    
    
   
    
    
   
}
